import imperituroard.core

#df = imperituroard.core.Ard()

#ast = df.send_telegram_message("dima test",

#print ast

#print df.ping_check()


dd = imperituroard.core.ArdUnbound("https://api.telegram.org/bot544376052:AAFBdb6CfxNR6rEGVUAGUc6iLdxdHFLx1IU/sendMessage", "-207244766")

dd.processes_check()